#
# spec file for package python-ytmusicapi
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-ytmusicapi
Version:        1.9.1
Release:        1.1
Summary:        Unofficial API for YouTube Music
License:        MIT
URL:            https://github.com/sigma67/ytmusicapi
Source:         https://files.pythonhosted.org/packages/source/y/ytmusicapi/ytmusicapi-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools >= 65}
BuildRequires:  %{python_module setuptools_scm >= 7}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-requests >= 2.22
Requires(post): update-alternatives
Requires(preun): update-alternatives
BuildArch:      noarch
%python_subpackages

%description
Unofficial API for YouTube Music

%prep
%autosetup -p1 -n ytmusicapi-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/ytmusicapi
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# Requires network access
# %%pytest

%post
%python_install_alternative ytmusicapi

%postun
%python_uninstall_alternative ytmusicapi

%files %{python_files}
%doc README.rst
%license LICENSE
%python_alternative %{_bindir}/ytmusicapi
%{python_sitelib}/ytmusicapi
%{python_sitelib}/ytmusicapi-%{version}.dist-info

%changelog
* Fri Dec 27 2024 Christophe Marin <christophe@krop.fr>
- Update to 1.9.1
  * fix(setup): Use resolve() before invoking as_uri()
  * search: exclude "Single"/"EP" text from album artist list
  * add_history_item: update doc and check for authentication
  * doc: restructure reference
* Sat Dec 21 2024 Christophe Marin <christophe@krop.fr>
- Update to 1.9.0
  Features:
  * updated OAuth setup CLI implementation to require client ID
    and secret via YouTube Data API. Please check the updated
    documentation for usage and instructions to create the
    credentials.
  * added optional parameters for OAuth client ID and secret to
    setup
  * remove_search_suggestions: added new function to remove
    search suggestion
  * added option to get_lyrics to retrieve timestamped lyrics
    instead
  Fixes:
  * fixed duration parsing for very long videos
  * fixed get_history crash due to server-side update
  * get_playlist: join multiple title runs
  * fix "get_album doesn't fetch audioPlaylistId for some albums"
* Fri Nov 15 2024 Adrian Schröter <adrian@suse.de>
- Update to 1.8.2
  * fix(playlists): handle missing regex group in trackCount
  * create_playlist: raise error when invalid characters are pa…
  * upload_song: add error when file exceeds limit of 300MB
  * refactor: use pathlib
  * search: fix missing artists when filtering songs/videos
  * search: fix missing playlistId for album results while authenticated
  * attempt to find runs in subtitle if not in title
* Wed Aug 28 2024 Christophe Marin <christophe@krop.fr>
- Update to 1.8.1
  * search: fix playlistId on album results
  * get_library_upload_*: fix 'v1.8.0 makes no songs to be found'
  * get_playlist: small additions to documentation
* Tue Aug  6 2024 Christophe Marin <christophe@krop.fr>
- Update to 1.8.0
  Features:
  * introduce exception classes
  * get_user_videos to get full list of user videos based on
    result of get_user
  Fixes:
  * get_playlist: fix title for podcast episodes
  * get_playlist: re-add thumbnails
  * get_podcast: fix edge case when first subtitle is missing
  * library uploads: fix broken index after downloads rollout
  Misc:
  * coverage: remove code for old playlist format
* Thu Jul 18 2024 Christophe Marin <christophe@krop.fr>
- Update to 1.7.5
  * podcasts: fixed a crash by returning blank album author ID
    when it doesn't exist
  * get_album: fix invalid track list artists
  * get_playlist: fix korean language by extracting song count
    from text using regex
  Changes from 1.7.4:
  * fixed get_album other_versions
  * fixed get_episodes_playlist
  * edit_playlist: Allow moving title to bottom of playlist
  * get_playlist: title, artists and album are correctly resolved
    in collaborative playlists
  * fix sum_total_duration failing if duration_seconds is not an
    int
* Sun Jun 16 2024 Christophe Marin <christophe@krop.fr>
- Update to 1.7.3
  * playlist search result "itemCount" field cast to int
  * add playlist id to album search
  * make parse_menu_playlists more error proof
  * get_home: remove "year" attribute from album results, parse
    podcasts and episodes
* Tue May 21 2024 Christophe Marin <christophe@krop.fr>
- Update to 1.7.2. Changes since 1.6.0:
  * get_account_info: get authenticated user's account info
  * get_library_channels: added type attribute to differentiate
    between channels and artists
  * get_artist: now supports shows from the artists view,
    improved documentation
  * support new A/B test formats for get_playlist and get_album
  * adding Optional type hinting for limits parameters
  * get_library_upload_songs: Gracefully retrieve uploaded songs
    with a blank duration
* Mon Mar 11 2024 Christophe Marin <christophe@krop.fr>
- Update to 1.6.0
  * New endpoints:
  * get_account_info
  * get_library_podcasts
  * get_library_channels
  * get_channel
  * get_channel_episodes
  * get_episodes_playlist
* Tue Mar  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 1.5.4
  * Fix parsing of album and views in parse_playlist_items
  * get_episode: support progress percentage
  * nav() now displays some debugging information on KeyError
* Fri Feb 23 2024 Christophe Marin <christophe@krop.fr>
- Update to 1.5.3
  * Revert "get_playlist: fix albums on tracks"
    (gh#sigma67/ytmusicapi#548)
  * Revert "get_charts: removed trending category (no longer
    available on YTM)"
* Wed Feb 21 2024 Christophe Marin <christophe@krop.fr>
- Init python-ytmusicapi. Needed by audiotube
